@@ -230,18 +230,20 @@ output$report_r <- renderUI({
     ),
     shinyAce::aceEditor(
       "r_edit",
-      selectionId = "r_edit_selection",
+      selectionId = "selection",
       mode = "r",
       theme = getOption("radiant.ace_theme", default = "tomorrow"),
       wordWrap = TRUE,
       height = "auto",
       value = state_init("r_edit", r_example) %>% fix_smart(),
+      placeholder = "Enter R-code for analysis here and press the Knit report button to run it.\nClick the ? icon on the top left of your screen for more information",
       vimKeyBinding = getOption("radiant.ace_vim.keys", default = FALSE),
-      hotkeys = list(r_hotkey = list(win = "CTRL-ENTER", mac = "CMD-ENTER")),
+      code_hotkeys = list("r", list(hotkey = list(win = "CTRL-ENTER|SHIFT-ENTER", mac = "CMD-ENTER|SHIFT-ENTER"))),
       tabSize = getOption("radiant.ace_tabSize", 2),
       useSoftTabs = getOption("radiant.ace_useSoftTabs", TRUE),
       showInvisibles = getOption("radiant.ace_showInvisibles", FALSE),
       autoComplete = getOption("radiant.ace_autoComplete", "live"),
+      autoCompleters = c("static", "text"),
       autoCompleteList = isolate(radiant_auto_complete())
     ),
     htmlOutput("r_knitted"),
@@ -251,6 +253,7 @@ output$report_r <- renderUI({
 
 ## auto completion of available R functions, datasets, and variables
 observe({
+  ## don't need to run until report generated
   req(report_r$report > 1)
   shinyAce::updateAceEditor(
     session, "r_edit",
@@ -271,7 +274,7 @@ observeEvent(input$r_clear, {
 })
 
 observe({
-  input$r_hotkey
+  input$r_edit_hotkey
   if (!is.null(input$r_knit)) {
     isolate({
       report_r$report <- report_r$report + 1
@@ -339,8 +342,8 @@ output$r_knitted <- renderUI({
         } else if (!is_empty(input$r_edit)) {
           if (!is_empty(input$r_edit_selection, "")) {
             report <- input$r_edit_selection
-          } else if (!is_empty(input$r_hotkey$line, "") && report_r$knit_button == 0) {
-            report <- input$r_hotkey$line
+          } else if (!is_empty(input$r_edit_hotkey$line, "") && report_r$knit_button == 0) {
+            report <- input$r_edit_hotkey$line
           } else {
             report <- input$r_edit
             ## hack to allow processing current line
@@ -348,7 +351,7 @@ output$r_knitted <- renderUI({
           }
         }
         report <- paste0("\n```{r echo = TRUE}\n", report, "\n```\n")
-        knit_it(report)
+        knit_it(report, type = "r")
       })
     }
   })
@@ -420,7 +423,9 @@ observeEvent(input$r_read_files, {
   if (is.integer(input$r_read_files)) return()
   path <- shinyFiles::parseFilePaths(sf_volumes, input$r_read_files)
   if (inherits(path, "try-error") || is_empty(path$datapath)) return()
-  pdir <- getOption("radiant.project_dir", default = radiant.data::find_home())
+  ldir <- getOption("radiant.launch_dir", default = radiant.data::find_home())
+  pdir <- getOption("radiant.project_dir", default = ldir)
+
   cmd <- read_files(path$datapath, pdir = pdir, type = "r", clipboard = FALSE, radiant = TRUE)
 
   if (!is_empty(cmd)) {
