@@ -9,7 +9,7 @@ rmd_generate <- c(
   "Auto paste" = "auto",
   "Manual paste" = "manual"
 )
-rmd_save_type <- c("Notebook", "HTML", "PDF", "Word", "Rmd")
+rmd_save_type <- c("Notebook", "HTML", "PDF", "Word", "Powerpoint", "Rmd")
 rmd_set <- c("To Rmd", "auto", "manual")
 rmd_set_rstudio <- c("To Rmd", "To R")
 
@@ -103,20 +103,17 @@ By clicking the `Knit report (Rmd)` button or pressing CTRL-enter (CMD-enter on
 
 Below is some code generated by Radiant to produce a scatterplot / heatmap of the price of diamonds versus carats. The colors in the plot reflect the clarity of the diamond.
 
-```{r fig.width = 7, fig.height = 5}
+```{r fig.width = 7, fig.height = 5, dpi = 96}
 visualize(
   diamonds,
   xvar = \"carat\",
   yvar = \"price\",
   type = \"scatter\",
+  nrobs = 1000,
   color = \"clarity\",
-  custom = TRUE
-) +
-  labs(
-    title = \"Diamond prices\",
-    x = \"Carats\",
-    y = \"Price ($)\"
-  )
+  labs = list(title = \"Diamond prices\", x = \"Carats\", y = \"Price ($)\"),
+  custom = FALSE
+)
 ```
 
 > **Put your own code here or delete this sample report and create your own**
@@ -338,18 +335,20 @@ output$report_rmd <- renderUI({
     ),
     shinyAce::aceEditor(
       "rmd_edit",
-      selectionId = "rmd_edit_selection",
+      selectionId = "selection",
       mode = "markdown",
       theme = getOption("radiant.ace_theme", default = "tomorrow"),
       wordWrap = TRUE,
       height = "auto",
       value = state_init("rmd_edit", rmd_example) %>% fix_smart(),
+      placeholder = "Type text for your report using markdown to format it\n(http://commonmark.org/help/). Add R-code to include\nyour analysis results in the report as well. Click the ?\nicon on the top left of your screen for more information",
       vimKeyBinding = getOption("radiant.ace_vim.keys", default = FALSE),
-      hotkeys = list(rmd_hotkey = list(win = "CTRL-ENTER", mac = "CMD-ENTER")),
+      code_hotkeys = list("r", list(hotkey = list(win = "CTRL-ENTER|SHIFT-ENTER", mac = "CMD-ENTER|SHIFT-ENTER"))),
       tabSize = getOption("radiant.ace_tabSize", 2),
       useSoftTabs = getOption("radiant.ace_useSoftTabs", TRUE),
       showInvisibles = getOption("radiant.ace_showInvisibles", FALSE),
       autoComplete = getOption("radiant.ace_autoComplete", "live"),
+      autoCompleters = c("static", "text"),
       autoCompleteList = isolate(radiant_auto_complete())
     ),
     htmlOutput("rmd_knitted"),
@@ -380,7 +379,7 @@ observeEvent(input$rmd_clear, {
 })
 
 observe({
-  input$rmd_hotkey
+  input$rmd_edit_hotkey
   if (!is.null(input$rmd_knit)) {
     isolate({
       report_rmd$report <- report_rmd$report + 1
@@ -445,8 +444,8 @@ rmd_knitted <- eventReactive(report_rmd$report != 1, {
       } else if (!is_empty(input$rmd_edit)) {
         if (!is_empty(input$rmd_edit_selection, "")) {
           report <- input$rmd_edit_selection
-        } else if (!is_empty(input$rmd_hotkey$line, "") && report_rmd$knit_button == 0) {
-          report <- input$rmd_hotkey$line
+        } else if (!is_empty(input$rmd_edit_hotkey$line, "") && report_rmd$knit_button == 0) {
+          report <- input$rmd_edit_hotkey$line
         } else {
           report <- input$rmd_edit
           ## hack to allow processing current line
@@ -529,7 +528,9 @@ observeEvent(input$rmd_read_files, {
   if (is.integer(input$rmd_read_files)) return()
   path <- shinyFiles::parseFilePaths(sf_volumes, input$rmd_read_files)
   if (inherits(path, "try-error") || is_empty(path$datapath)) return()
-  pdir <- getOption("radiant.project_dir", default = radiant.data::find_home())
+  ldir <- getOption("radiant.launch_dir", default = radiant.data::find_home())
+  pdir <- getOption("radiant.project_dir", default = ldir)
+
   cmd <- read_files(path$datapath, pdir = pdir, type = "rmd", clipboard = FALSE, radiant = TRUE)
   if (!is_empty(cmd)) {
     update_report_fun(cmd, type = "rmd", rfiles = TRUE)
